@@ -1,14 +1,11 @@
 ## -*- Mode: CPerl -*-
 ##
-## File: DiaColloDB::Compat::v0_09.pm
+## File: DiaColloDB::Compat::v0_08.pm
 ## Author: Bryan Jurish <moocow@cpan.org>
 ## Description: DiaColloDB utilities: compatibility modules: v0.08.x
 
-package DiaColloDB::Compat::v0_09;
-use DiaColloDB::Compat::v0_09::Relation;
-use DiaColloDB::Compat::v0_09::Relation::Cofreqs;
-use DiaColloDB::Compat::v0_09::Relation::Unigrams;
-use DiaColloDB::Compat::v0_09::DiaColloDB;
+package DiaColloDB::Compat::v0_08;
+use DiaColloDB::Compat::v0_08::MultiMapFile;
 use Carp;
 use strict;
 
