@@ -43,6 +43,13 @@ sub new {
 ##==============================================================================
 ## API: I/O
 
+
+## $ext = $doc->extension()
+##  + default extension, for Corpus::Compiled
+sub extension {
+  return '.tcf';
+}
+
 ##--------------------------------------------------------------
 ## API: I/O: parse
 
