@@ -5,7 +5,7 @@
 
 package DiaColloDB::EnumFile::FixedMap;
 use DiaColloDB::EnumFile::FixedLen;
-use DiaColloDB::Utils qw(:fcntl :json :regex :pack);
+use DiaColloDB::Utils qw(:fcntl :file :json :regex :pack);
 use File::Map qw(map_handle);
 use Fcntl qw(:DEFAULT :seek);
 use strict;
@@ -73,6 +73,13 @@ sub new {
 sub open {
   my ($enum,$base,$flags) = @_;
   $enum->SUPER::open($base,$flags) or return undef;
+  return $enum->remap();
+}
+
+## $enum_or_undef = $enum->remap()
+##  + re-maps mmap buffers from enum handles
+sub remap {
+  my $enum = shift;
 
   ##-- mmap handles
   my $mapmode = fcperl($enum->{flags});
@@ -104,6 +111,15 @@ sub opened {
     );
 }
 
+## $bool = $enum->reopen()
+##  + re-opens datafiles
+##  + override also remaps buffers
+sub reopen {
+  my $enum = shift;
+  return $enum->SUPER::reopen() && $enum->remap();
+}
+
+
 ## $bool = $enum->dirty()
 ##  + returns true iff some in-memory structures haven't been flushed to disk
 ##  + INHERITED
