@@ -29,8 +29,15 @@ BEGIN {
     }
     $MODULE //= '';
   }
-  *import = $MODULE ? UNIVERSAL::can($MODULE,'import') : sub {}
-    if (!UNIVERSAL::can(__PACKAGE__,'import'));
+}
+
+sub import {
+  if ($MODULE) {
+    #my $that   = shift;
+    my $caller = caller;
+    my $sub = eval qq{sub { package $caller; $MODULE->import(); } };
+    $sub->(@_);
+  }
 }
 
 ## $threadid = CLASS->tid()
@@ -39,7 +46,6 @@ sub tid {
 }
 
 
-
 1; ##-- be happy
 
 __END__
